Install `imbalanced_ensemble`
*******************************

Prerequisites
=============

The following packages are requirements:

    * ``numpy``
    * ``scipy``
    * ``pandas``
    * ``joblib``
    * ``sklearn``
    * ``matplotlib``
    * ``seaborn``

Installation
============

Install from PyPi
^^^^^^^^^^^^^^^^^

You can install imbalanced-ensemble from 
`PyPI <https://pypi.org/project/imbalanced-ensemble/>`__ by running:

.. code-block:: bash

    > pip install imbalanced-ensemble

Clone from GitHub
^^^^^^^^^^^^^^^^^

Or you can install imbalanced-ensemble locally:

.. code-block:: bash
    
    > git clone https://github.com/ZhiningLiu1998/imbalanced-ensemble.git
    > cd imbalanced-ensemble
    > pip install .